==> Tagz-1.0.0.zip: Tagz/lang/de.php <==
<?php
$LANG = array(
 'P_MENU'=>'0',
 'L_MENU_TAGS'=>'Schlüsselwörter',
 'L_TITLE'=>'Bearbeiten Sie die Site-Keywords',
 'L_DESCRIPTION'=>'Site-Tags verwalten Löschen Sie den Satz von Schlüsselwörtern oder benennen Sie ihn um.',
#admin
 'L_CANCEL'=>'Alle abbrechen',
 'L_DEVIENT'=>'wird',
 'L_POUR'=>'für',
 'L_SEARCH'=>'Suchen Sie in Artikeln mit diesem Schlüsselwort',
 'L_RESTORE'=>'wiederherstellen',
 'L_DEL'=>'auslöschen',
 'L_RESTORE_ALL'=>'Stellen Sie alle leeren Felder wieder her',
 'L_DEL_ALL'=>'Löschen Sie alle Felder',
 'L_ART_NUM'=>'Für die Artikel mit Nummer (n)',
 'L_HELP_TAG_FIELD'=>'Wenn das Feld leer ist, wird das Schlüsselwort nach dem Speichern gelöscht.'.PHP_EOL.'La combinaison de touche Ctrl + z permet d’annuler',
 'L_TAGS_REFRESH'=>'auffrischen',
 'L_TAGS_REFRESHED_BY_ARTICLES'=>'Tags.xml-Datei mit den Schlüsselwörtern der Artikel aktualisiert',
 'L_TAG_PLACEHOLDER'=>'Wird gelöscht, wenn leer gelassen wird',
 'L_DEDUPLICATED'=>'deduplizierten',
 'L_IN_REALITY'=>'In Wirklichkeit',
 'L_IS_UNIK'=>'Einzigartig (ist solo)',
 'L_DOUBLES'=>'doppelt',
 'L_TRIPLES'=>'Tripel',
 'L_QUADRUPLES'=>'vervierfachen',
 'L_QUINTUPLES'=>'verfünffachen',
 'L_SEXTUPLES'=>'sextuple',
 'L_SEPTUPLES'=>'sevenfold',
#config
 'L_ACCES'=>'Art (en) von Konto (e) *, die zum Zugriff auf das Plugin berechtigt sind',
 'L_HELP_ACCES'=>'Welche Profile * dürfen das Plugin verwenden? Liste durch Kommas getrennt (Standard PROFIL_ADMIN, PROFIL_MANAGER).',
 'L_DENY'=>'Benutzern ist es untersagt, auf das Plugin zuzugreifen',
 'L_HELP_DENY'=>'Welches sind die Bezeichner der Benutzer, denen das Plugin nicht erlaubt ist. Kommagetrennte Liste (z. B. 001.002.007).'
);
?>

==> Tagz-1.0.4.zip: Tagz/lang/de.php <==
<?php
$LANG = array(
 'P_MENU'=>'0',
 'L_MENU_TAGS'=>'Schlüsselwörter',
 'L_TITLE'=>'Bearbeiten Sie die Site-Keywords',
 'L_DESCRIPTION'=>'Site-Tags verwalten Löschen Sie den Satz von Schlüsselwörtern oder benennen Sie ihn um.',
 'L_FILTER_TAGS'=>'Schlüsselwörter filtern',
 'L_FILTER_TAGS_PH'=>'Wortfilter',
 'L_CANCEL'=>'Alle abbrechen',
 'L_DEVIENT'=>'wird',
 'L_POUR'=>'für',
 'L_SEARCH'=>'Suchen Sie in Artikeln mit diesem Schlüsselwort',
 'L_RESTORE'=>'wiederherstellen',
 'L_DEL'=>'auslöschen',
 'L_RESTORE_ALL'=>'Stellen Sie alle leeren Felder wieder her',
 'L_DEL_ALL'=>'Löschen Sie alle Felder',
 'L_ART_NUM'=>'Für die Artikel mit Nummer (n)',
 'L_HELP_TAG_FIELD'=>'Wenn das Feld leer ist, wird das Schlüsselwort nach dem Speichern gelöscht.',
 'L_HELP_TAG_CTRLZ'=>'Die Kombination der Strg-z-Tasten ermöglicht es Ihnen,',
 'L_TAGS_REFRESH'=>'auffrischen',
 'L_TAGS_REFRESHED_BY_ARTICLES'=>'Tags.xml-Datei mit den Schlüsselwörtern der Artikel aktualisiert',
 'L_TAG_PLACEHOLDER'=>'Wird gelöscht, wenn leer gelassen wird',
 'L_DEDUPLICATED'=>'deduplizierten',
 'L_IN_REALITY'=>'In Wirklichkeit',
 'L_IS_UNIK'=>'Einzigartig (ist solo)',
 'L_DOUBLES'=>'doppelt',
 'L_TRIPLES'=>'Tripel',
 'L_QUADRUPLES'=>'vervierfachen',
 'L_QUINTUPLES'=>'verfünffachen',
 'L_SEXTUPLES'=>'sextuple',
 'L_SEPTUPLES'=>'sevenfold',
 'L_OCTUPLES'=>'Oktupel',
 'L_NONUPLES'=>'Nichtupel',
 'L_DECUPLES'=>'Zehnfach',
 'L_ACCES'=>'Art (en) von Konto (e) *, die zum Zugriff auf das Plugin berechtigt sind',
 'L_HELP_ACCES'=>'Welche Profile * dürfen das Plugin verwenden? Liste durch Kommas getrennt (Standard PROFIL_ADMIN, PROFIL_MANAGER).',
 'L_DENY'=>'Benutzern ist es untersagt, auf das Plugin zuzugreifen',
 'L_HELP_DENY'=>'Welches sind die Bezeichner der Benutzer, denen das Plugin nicht erlaubt ist. Kommagetrennte Liste (z. B. 001.002.007).',
);
?>
